/**
 * 环境配置
 */
const config = {
  // 开发环境配置
  development: {
    port: 8991,
    host: '0.0.0.0',
    cors: {
      origin: '*',
      methods: ['GET', 'POST', 'PUT', 'DELETE', 'OPTIONS'],
      allowedHeaders: ['Content-Type', 'Authorization']
    },
    rateLimit: {
      windowMs: 15 * 60 * 1000, // 15分钟
      max: 100 // 限制每个IP 15分钟内最多100个请求
    },
    browser: {
      headless: true,
      args: ['--no-sandbox', '--disable-setuid-sandbox']
    },
    logging: {
      level: 'debug',
      format: 'dev'
    }
  },

  // 生产环境配置
  production: {
    port: process.env.PORT || 8991,
    host: '0.0.0.0',
    cors: {
      origin: process.env.ALLOWED_ORIGINS?.split(',') || '*',
      methods: ['GET', 'POST'],
      allowedHeaders: ['Content-Type', 'Authorization']
    },
    rateLimit: {
      windowMs: 15 * 60 * 1000,
      max: 50 // 生产环境限制更严格
    },
    browser: {
      headless: true,
      args: [
        '--no-sandbox',
        '--disable-setuid-sandbox',
        '--disable-dev-shm-usage',
        '--disable-accelerated-2d-canvas',
        '--disable-gpu'
      ]
    },
    logging: {
      level: 'info',
      format: 'combined'
    }
  }
};

// 获取当前环境
const env = process.env.NODE_ENV || 'development';

// 导出当前环境的配置
module.exports = config[env]; 