const express = require('express');
const router = express.Router();
const CrawlerFactory = require('../services/crawlerFactory');
const { createRateLimiter, validateRequest } = require('../middlewares/crawlerMiddleware');
const config = require('../config/crawler.config');

// 创建请求限制中间件
const rateLimiter = createRateLimiter({
  windowMs: 15 * 60 * 1000, // 15分钟
  max: 100 // 限制每个IP 15分钟内最多100个请求
});

/**
 * 获取商品信息
 * GET /api/product/info
 */
router.get('/product/info', rateLimiter, validateRequest, async (req, res, next) => {
  try {
    const { url, platform, needScreenshot } = req.query;
    
    // 创建爬虫实例
    const crawler = CrawlerFactory.createCrawler(platform, config[platform]);
    
    // 抓取商品信息
    const data = await crawler.crawl(
      url,
      needScreenshot === 'true'
    );
    
    res.json({
      success: true,
      data
    });
  } catch (error) {
    next(error);
  }
});

/**
 * 获取支持的平台列表
 * GET /api/platforms
 */
router.get('/platforms', (req, res) => {
  res.json({
    success: true,
    data: CrawlerFactory.getSupportedPlatforms()
  });
});

module.exports = router; 