const AmazonCrawler = require('./crawlers/amazon/AmazonCrawler');
const RakutenCrawler = require('./crawlers/rakuten/RakutenCrawler');
const CrawlerError = require('./errors/CrawlerError');

/**
 * 爬虫工厂类
 * 用于创建不同平台的爬虫实例
 */
class CrawlerFactory {
  /**
   * 创建爬虫实例
   * @param {string} platform - 平台名称
   * @param {Object} config - 配置信息
   * @returns {BaseCrawler} 爬虫实例
   * @throws {CrawlerError} 不支持的平台
   */
  static createCrawler(platform, config = {}) {
    switch (platform.toLowerCase()) {
      case 'amazon':
        return new AmazonCrawler(config);
      case 'rakuten':
        return new RakutenCrawler(config);
      // case 'yahoo':
      //   return new YahooCrawler(config);
      default:
        throw new CrawlerError(
          `不支持的平台: ${platform}`,
          'UNSUPPORTED_PLATFORM',
          platform
        );
    }
  }

  /**
   * 获取支持的平台列表
   * @returns {string[]} 平台列表
   */
  static getSupportedPlatforms() {
    return ['amazon']; // 可以在这里添加其他支持的平台
  }
}

module.exports = CrawlerFactory; 